PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Defs.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Namespaces | Macros | Typedefs
Defs.hpp File Reference
`#include <cstdint>`
`#include <format>`

Go to the source code of this file.

## Namespaces
namespace | fmt

## Macros
#define | std_08x std::hex << std::setw(8) << std::setfill('0')
#define | PEDANTIC(args...)
#define | WITH_LOCK(a, b)
#define | WITH_RLOCK(a, b)
#define | WITH_WLOCK(a, b)

## Typedefs
using | Real = double
using | uint = unsigned int

## Macro Definition Documentation

## ◆ PEDANTIC

#define PEDANTIC | ( |  | args... | ) |

Value:
args

## ◆ std_08x

#define std_08x std::hex << std::setw(8) << std::setfill('0')

## ◆ WITH_LOCK

#define WITH_LOCK | ( |  | a,
|  |  | b )

Value:
do { std::lock_guard _lock((a)->getLock()); b; } while(0)

## ◆ WITH_RLOCK

#define WITH_RLOCK | ( |  | a,
|  |  | b )

Value:
do { std::shared_lock _lock((a)->getLock()); b; } while(0)

## ◆ WITH_WLOCK

#define WITH_WLOCK | ( |  | a,
|  |  | b )

Value:
do { std::unique_lock _lock((a)->getLock()); b; } while(0)

## Typedef Documentation

## ◆ Real

using Real = double

## ◆ uint

using uint = unsigned int